@@ -1,18 +1,23 @@
 """Utils related to the NRN simulator"""
 import logging
-import multiprocessing
 import multiprocessing.pool
 from pathlib import Path
 from typing import List, Sequence, Union
 
 import bluepyopt.ephys as ephys
-import neuron
 import numpy as np
 from neurom import COLS, NeuriteType, iter_sections, load_neuron
 from neurom.core import NeuriteIter
 from numpy.testing import assert_almost_equal
 
-L = logging.getLogger('morph_tool')
+try:
+    import neuron
+except ImportError as e:
+    raise ImportError(
+        'morph-tool[nrn] is not installed. Please install: pip install morph-tool[nrn]'
+    ) from e
+
+L = logging.getLogger(__name__)
 
 
 def get_NRN_cell(filename: Path):
@@ -273,7 +278,24 @@ class NestedPool(multiprocessing.pool.Pool):  # pylint: disable=abstract-method
 
     class Process(multiprocessing.Process):
         """Class that represents a non-daemon process"""
-        daemon = False
+
+        def __init__(self, *args, **kwargs):
+            """Ensures group=None to avoid exception from multiprocessing.
+
+            Note:
+                The exception raised by multiprocessing is:
+                AssertionError: group argument must be None for now
+            """
+            kwargs.pop("group", None)
+            super().__init__(None, *args[1:], **kwargs)
+
+        @property
+        def daemon(self):
+            return False
+
+        @daemon.setter
+        def daemon(self, value):
+            pass
 
 
 def isolate(func):
